@@ -918,6 +918,7 @@ def test_dataclass_with_multiple_inheritance() -> None:
     """Regression test for dataclasses with multiple inheritance.
 
     Reported in https://github.com/PyCQA/pylint/issues/7427
+    Reported in https://github.com/PyCQA/pylint/issues/7434
     """
     first, second, overwritten, overwriting, mixed = astroid.extract_node(
         """
@@ -991,6 +992,75 @@ def test_dataclass_with_multiple_inheritance() -> None:
     assert [a.name for a in mixed_init.args.args] == ["self", "_abc", "ghi"]
     assert [a.value for a in mixed_init.args.defaults] == [1, 3]
 
+    first = astroid.extract_node(
+        """
+    from dataclasses import dataclass
+
+    @dataclass
+    class BaseParent:
+        required: bool
+
+    @dataclass
+    class FirstChild(BaseParent):
+        ...
+
+    @dataclass
+    class SecondChild(BaseParent):
+        optional: bool = False
+
+    @dataclass
+    class GrandChild(FirstChild, SecondChild):
+        ...
+
+    GrandChild.__init__  #@
+    """
+    )
+
+    first_init: bases.UnboundMethod = next(first.infer())
+    assert [a.name for a in first_init.args.args] == ["self", "required", "optional"]
+    assert [a.value for a in first_init.args.defaults] == [False]
+
+
+@pytest.mark.xfail(reason="Transforms returning Uninferable isn't supported.")
+def test_dataclass_non_default_argument_after_default() -> None:
+    """Test that a non-default argument after a default argument is not allowed.
+
+    This should succeed, but the dataclass brain is a transform
+    which currently can't return an Uninferable correctly. Therefore, we can't
+    set the dataclass ClassDef node to be Uninferable currently.
+    Eventually it can be merged into test_dataclass_with_multiple_inheritance.
+    """
+
+    impossible = astroid.extract_node(
+        """
+    from dataclasses import dataclass
+
+    @dataclass
+    class BaseParent:
+        required: bool
+
+    @dataclass
+    class FirstChild(BaseParent):
+        ...
+
+    @dataclass
+    class SecondChild(BaseParent):
+        optional: bool = False
+
+    @dataclass
+    class ThirdChild:
+        other: bool = False
+
+    @dataclass
+    class ImpossibleGrandChild(FirstChild, SecondChild, ThirdChild):
+        ...
+
+    ImpossibleGrandChild() #@
+    """
+    )
+
+    assert next(impossible.infer()) is Uninferable
+
 
 def test_dataclass_inits_of_non_dataclasses() -> None:
     """Regression test for __init__ mangling for non dataclasses.
