@@ -1268,6 +1268,22 @@ class ClassNodeTest(ModuleLoader, unittest.TestCase):
         self.assertIsInstance(attr1, nodes.AssignName)
         self.assertEqual(attr1.name, "attr")
 
+    @staticmethod
+    def test_getattr_with_enpty_annassign() -> None:
+        code = """
+            class Parent:
+                attr: int = 2
+
+            class Child(Parent):  #@
+                attr: int
+        """
+        child = extract_node(code)
+        attr = child.getattr("attr")
+        assert len(attr) == 1
+        assert isinstance(attr[0], nodes.AssignName)
+        assert attr[0].name == "attr"
+        assert attr[0].lineno == 3
+
     def test_function_with_decorator_lineno(self) -> None:
         data = """
             @f(a=2,
@@ -2534,6 +2550,21 @@ def test_enums_type_annotation_no_value(annotation) -> None:
     assert inferred_member_value.value is None
 
 
+def test_enums_value2member_map_() -> None:
+    """Check the `_value2member_map_` member is present in an Enum class"""
+    node = builder.extract_node(
+        """
+    from enum import Enum
+    class Veg(Enum):
+        TOMATO: 1
+
+    Veg
+    """
+    )
+    inferred_class = node.inferred()[0]
+    assert "_value2member_map_" in inferred_class.locals
+
+
 @pytest.mark.parametrize("annotation, value", [("int", 42), ("bytes", b"")])
 def test_enums_type_annotation_non_str_member(annotation, value) -> None:
     """A type-annotated member of an Enum class where:
